from aioanticaptcha.antinetworking import *
import asyncio


class hCaptchaProxyon(antiNetworking):
    async def solve_and_return_solution(self):
        if (
            await self.create_task(
                {
                    "clientKey": self.client_key,
                    "task": {
                        "type": "HCaptchaTask",
                        "websiteURL": self.website_url,
                        "websiteKey": self.website_key,
                        "proxyType": self.proxy_type,
                        "proxyAddress": self.proxy_address,
                        "proxyPort": self.proxy_port,
                        "proxyLogin": self.proxy_login,
                        "proxyPassword": self.proxy_password,
                        "userAgent": self.user_agent,
                        "cookies": self.cookies,
                    },
                }
            )
            == 1
        ):
            self.log("created task with id " + str(self.task_id))
        else:
            self.log("could not create task")
            self.log(self.err_string)
            return 0
        # checking result
        await asyncio.sleep(3)
        task_result = await self.wait_for_result(300)
        if task_result == 0:
            return 0
        else:
            return task_result["solution"]["gRecaptchaResponse"]



from aioanticaptcha.antinetworking import *
import asyncio


class recaptchaV3EnterpriseProxyless(antiNetworking):

    min_score = 0.9
    page_action = ""

    async def solve_and_return_solution(self):
        if (
            await self.create_task(
                {
                    "clientKey": self.client_key,
                    "task": {
                        "type": "RecaptchaV3TaskProxyless",
                        "websiteURL": self.website_url,
                        "websiteKey": self.website_key,
                        "minScore": self.min_score,
                        "pageAction": self.page_action,
                        "isEnterprise": True,
                    },
                }
            )
            == 1
        ):
            self.log("created task with id " + str(self.task_id))
        else:
            self.log("could not create task")
            self.log(self.err_string)
            return 0
        # checking result
        await asyncio.sleep(3)
        task_result = await self.wait_for_result(60)
        if task_result == 0:
            return 0
        else:
            return task_result["solution"]["gRecaptchaResponse"]

    def set_page_action(self, value):
        self.page_action = value

    def set_min_score(self, value):
        available_scores = [0.5, 0.7, 0.9]
        if value in available_scores:
            self.min_score = value
        else:
            self.min_score = 0.9



from aioanticaptcha.antinetworking import *
import asyncio


class antigateTask(antiNetworking):

    template_name = ""
    variables = {}

    def push_variable(self, task_id, name, value):
        result = self.make_request(
            "pushAntiGateVariable",
            {
                "clientKey": self.client_key,
                "taskId": self.task_id,
                "name": name,
                "value": value,
            },
        )
        if result == 0:
            return 0
        else:
            if result["errorId"] == 0:
                return 1
            else:
                return 0

    async def send_antigate_task(self):
        if (
            await self.create_task(
                {
                    "clientKey": self.client_key,
                    "task": {
                        "type": "AntiGateTask",
                        "websiteURL": self.website_url,
                        "templateName": self.template_name,
                        "variables": self.variables,
                        "proxyAddress": self.proxy_address,
                        "proxyPort": self.proxy_port,
                        "proxyLogin": self.proxy_login,
                        "proxyPassword": self.proxy_password,
                    },
                }
            )
            == 1
        ):
            self.log("created task with id " + str(self.task_id))
            return self.task_id
        else:
            self.log("could not create task")
            self.log(self.err_string)
            return 0

    async def solve_and_return_solution(self):
        if (
            await self.create_task(
                {
                    "clientKey": self.client_key,
                    "task": {
                        "type": "AntiGateTask",
                        "websiteURL": self.website_url,
                        "templateName": self.template_name,
                        "variables": self.variables,
                        "proxyAddress": self.proxy_address,
                        "proxyPort": self.proxy_port,
                        "proxyLogin": self.proxy_login,
                        "proxyPassword": self.proxy_password,
                    },
                }
            )
            == 1
        ):
            self.log("created task with id " + str(self.task_id))
        else:
            self.log("could not create task")
            self.log(self.err_string)
            return 0
        # checking result
        await asyncio.sleep(3)
        task_result = await self.wait_for_result(600)
        if task_result == 0:
            return 0
        else:
            return task_result["solution"]

    def set_template_name(self, value):
        self.template_name = value

    def set_variables(self, value):
        self.variables = value



import json
from datetime import datetime
import aiohttp
import asyncio

default_headers = {"Content-Type": "application/json",
                   "Accept": "application/json"}


class antiNetworking:

    client_key = ""
    website_url = ""
    website_key = ""
    website_stoken = ""
    recaptcha_data_s = ""
    recaptcha_enterprise_payload = None
    proxy_type = "http"
    proxy_address = ""
    proxy_port = 0
    proxy_login = ""
    proxy_password = ""
    user_agent = ""
    cookies = ""
    is_invisible = 0

    is_verbose = 0
    err_string = ""
    task_id = 0
    error_code = ""

    phrase = False
    case = False
    numeric = 0
    math = False
    minLength = 0
    maxLength = 0
    comment = False

    async def __aenter__(self):
        self.session = aiohttp.ClientSession()
        self.session.headers.update(default_headers)
        return self

    async def __aexit__(self, *exc):
        await self.session.close()

    async def get_balance(self):
        result = await self.make_request("getBalance", {"clientKey": self.client_key})
        if result != 0:
            return result["balance"]
        else:
            return -1

    async def create_task(self, post_data):

        new_task = await self.make_request("createTask", post_data)
        if new_task == 0:
            return 0
        else:
            if new_task["errorId"] == 0:
                self.task_id = new_task["taskId"]
                return 1
            else:
                self.error_code = new_task["errorCode"]
                self.err_string = (
                    "API error "
                    + new_task["errorCode"]
                    + ": "
                    + new_task["errorDescription"]
                )
                return 0

    async def wait_for_result(self, max_seconds=300, current_second=0):

        if current_second >= max_seconds:
            self.err_string = "task solution expired"
            return 0

        await asyncio.sleep(1)
        task_check = await self.make_request(
            "getTaskResult", {
                "clientKey": self.client_key, "taskId": self.task_id}
        )
        if task_check == 0:
            return 0
        else:
            if task_check["errorId"] == 0:
                if task_check["status"] == "processing":
                    self.log("task is still processing")
                    return await self.wait_for_result(max_seconds, current_second + 1)
                if task_check["status"] == "ready":
                    self.log("task solved")
                    return task_check
            else:
                self.error_code = task_check["errorCode"]
                self.err_string = (
                    "API error "
                    + task_check["errorCode"]
                    + ": "
                    + task_check["errorDescription"]
                )
                self.log(self.err_string)
                return 0

    async def report_incorrect_image_captcha(self):
        return await self.make_request(
            "reportIncorrectImageCaptcha",
            {"clientKey": self.client_key, "taskId": self.task_id},
        )

    async def report_incorrect_recaptcha(self):
        return await self.make_request(
            "reportIncorrectRecaptcha",
            {"clientKey": self.client_key, "taskId": self.task_id},
        )

    async def report_correct_recaptcha(self):
        return await self.make_request(
            "reportCorrectRecaptcha",
            {"clientKey": self.client_key, "taskId": self.task_id},
        )

    async def make_request(self, method, data):
        self.log("making request to " + method)

        try:
            response = await self.session.post(
                "https://api.anti-captcha.com/" + method, data=json.dumps(data)
            )
        except aiohttp.ClientConnectionError as err:
            print(err)
            self.log("HTTPError")
            self.err_string = "http_error"
            for errArg in err.args:
                if "Network is unreachable" in str(errArg):
                    self.err_string = "Network is unreachable"
                if "Connection refused" in str(errArg):
                    self.err_string = "Connection refused"
            return 0
        return await response.json()

    def set_key(self, value):
        self.client_key = value

    def set_website_url(self, value):
        self.website_url = value

    def set_website_key(self, value):
        self.website_key = value

    def set_website_stoken(self, value):
        self.website_stoken = value

    def set_data_s(self, value):
        self.recaptcha_data_s = value

    def set_enterprise_payload(self, value):
        self.recaptcha_enterprise_payload = value

    def set_proxy_type(self, value):
        self.proxy_type = value

    def set_proxy_address(self, value):
        self.proxy_address = value

    def set_proxy_port(self, value):
        self.proxy_port = value

    def set_proxy_login(self, value):
        self.proxy_login = value

    def set_proxy_password(self, value):
        self.proxy_password = value

    def set_user_agent(self, value):
        self.user_agent = value

    def set_cookies(self, value):
        self.cookies = value

    def set_is_invisible(self, value):
        self.is_invisible = value

    def set_verbose(self, value):
        self.is_verbose = value

    def log(self, msg):
        if self.is_verbose:
            print(msg)

    def get_time_stamp(self):
        return int((datetime.utcnow() - datetime(1970, 1, 1)).total_seconds())

    def set_phrase(self, value):
        self.phrase = value

    def set_case(self, value):
        self.case = value

    def set_numeric(self, value):
        self.numeric = value

    def set_math(self, value):
        self.math = value

    def set_minLength(self, value):
        self.minLength = value

    def set_maxLength(self, value):
        self.maxLength = value

    def set_comment(self, value):
        self.comment = value



from setuptools import find_packages, setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

VERSION = "1.2"
DESCRIPTION = "Async lib for  Anti-Captcha service."


# Setting up
setup(
    name="python3-aioanticaptcha",
    version=VERSION,
    author="André França",
    author_email="rsp.assistencia@gmail.com",
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=["aiohttp", "aiofiles"],
    url="https://github.com/andrersp/aioanticaptcha",
    keywords=["python", "anti-captcha", "async"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Operating System :: OS Independent",
    ],
)



from aioanticaptcha.antinetworking import *
import asyncio


class recaptchaV2Proxyon(antiNetworking):
    async def solve_and_return_solution(self):
        task = {
            "type": "RecaptchaV2Task",
            "websiteURL": self.website_url,
            "websiteKey": self.website_key,
            "websiteSToken": self.website_stoken,
            "recaptchaDataSValue": self.recaptcha_data_s,
            "proxyType": self.proxy_type,
            "proxyAddress": self.proxy_address,
            "proxyPort": self.proxy_port,
            "proxyLogin": self.proxy_login,
            "proxyPassword": self.proxy_password,
            "userAgent": self.user_agent,
            "cookies": self.cookies,
        }
        if self.is_invisible:
            task["isInvisible"] = True
        if await self.create_task({"clientKey": self.client_key, "task": task}) == 1:
            self.log("created task with id " + str(self.task_id))
        else:
            self.log("could not create task")
            self.log(self.err_string)
            return 0
        # checking result
        await asyncio.sleep(3)
        task_result = await self.wait_for_result(300)
        if task_result == 0:
            return 0
        else:
            return task_result["solution"]["gRecaptchaResponse"]



import aiofiles
from aioanticaptcha.antinetworking import *
from base64 import b64encode


class imagecaptcha(antiNetworking):
    async def solve_and_return_solution(self, file_path, **kwargs):

        try:
            async with aiofiles.open(file_path, "rb") as img:
                img_str = b64encode(await img.read()).decode("ascii")
                await img.close()
        except FileNotFoundError as exc:
            self.log("image not found")
            return 0

        task_data = {
            "type": "ImageToTextTask",
            "body": img_str,
            "phrase": self.phrase,
            "case": self.case,
            "numeric": self.numeric,
            "math": self.math,
            "minLength": self.minLength,
            "maxLength": self.maxLength,
            "comment": self.comment,
        }
        task_data.update(kwargs)
        if (
            await self.create_task({"clientKey": self.client_key, "task": task_data})
            == 1
        ):
            self.log("created task with id " + str(self.task_id))
        else:
            self.log("could not create task")
            self.log(self.err_string)
            return 0

        task_result = await self.wait_for_result(60)
        if task_result == 0:
            return 0
        else:
            return task_result["solution"]["text"]
